==> haskell-hslua-module-text-0.2.1-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-text
version:              0.2.1
visibility:           public
id:                   hslua-module-text-0.2.1-JF6twCde7JCA3ewu1Qdfkl
key:                  hslua-module-text-0.2.1-JF6twCde7JCA3ewu1Qdfkl
license:              MIT
copyright:            © 2017–2019 Albert Krewinkel
maintainer:           albert+hslua@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-text
synopsis:             Lua module for text
description:          UTF-8 aware subset of Lua'\''s `string` module.
category:             Foreign
abi:                  296eff3099f583d8b8f55a5174a8840b
exposed:              True
exposed-modules:      Foreign.Lua.Module.Text
import-dirs:          /usr/lib/ghc-8.10.1/site-local/hslua-module-text-0.2.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/hslua-module-text-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/hslua-module-text-0.2.1
hs-libraries:         HShslua-module-text-0.2.1-JF6twCde7JCA3ewu1Qdfkl
depends:
    base-4.14.0.0 bytestring-0.10.10.0
    hslua-1.1.0-6b734oa3rM4CcnaOffvZvO text-1.2.3.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-text/html/hslua-module-text.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-text-0.2.1-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-text
version:              0.2.1
visibility:           public
id:                   hslua-module-text-0.2.1-HDRHTlE1nkMBWMgznEtKkc
key:                  hslua-module-text-0.2.1-HDRHTlE1nkMBWMgznEtKkc
license:              MIT
copyright:            © 2017–2019 Albert Krewinkel
maintainer:           albert+hslua@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-text
synopsis:             Lua module for text
description:          UTF-8 aware subset of Lua'\''s `string` module.
category:             Foreign
abi:                  3af6feefd326e574e6cd72e6cda3dbdb
exposed:              True
exposed-modules:      Foreign.Lua.Module.Text
import-dirs:          /usr/lib/ghc-8.10.1/site-local/hslua-module-text-0.2.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/hslua-module-text-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/hslua-module-text-0.2.1
hs-libraries:         HShslua-module-text-0.2.1-HDRHTlE1nkMBWMgznEtKkc
depends:
    base-4.14.0.0 bytestring-0.10.10.0
    hslua-1.1.1-IWs78xIcUyQKcvwHT9rPzS text-1.2.3.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-text/html/hslua-module-text.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
